@@ -6,12 +6,12 @@ function _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoin
 }
 function _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpointProps(p) {
 }
+function _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint(p) {
+}
 function _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoint(p) {
 }
 function _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpoint(p) {
 }
-function _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint(p) {
-}
 function _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpoint(p) {
 }
 function print(name, deprecationMessage) {
@@ -29,5 +29,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpointOptions, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpoint };
+module.exports = { print, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpointOptions, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpointProps, _aws_cdk_aws_globalaccelerator_endpoints_InstanceEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_ApplicationLoadBalancerEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_NetworkLoadBalancerEndpoint, _aws_cdk_aws_globalaccelerator_endpoints_CfnEipEndpoint };
 module.exports.DeprecationError = DeprecationError;
